jsonschema: Python implementation of JSON Schema
================================================

Description
-----------

jsonschema is an implementation of JSON Schema for Python

License
-------

MIT License


Upstream Contact
----------------

Home page: http://github.com/Julian/jsonschema

Dependencies
------------

- Python
- Setuptools
- attrs
- importlib_metadata
- pyrsistent
